##  Overview
Use diagram versioning and import/export tools to control how your diagrams evolve and to reuse them across tools.
On this page, you’ll learn how to:
  * Work with version history for diagrams moved from free draw and data flow, including viewing versions, restoring, saving as new, and adding version information.
  * Compare diagram versions side by side to see what has changed.
  * Import from other diagrams in your workspace or from other tools, such as [_draw.io_![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fdraw.io%2F "http://draw.io/"), Lucidchart, and Visio.
  * Export diagrams as PDF, SVG, PNG, HTML embed code, or XML to share them or reuse them in other tools like draw.io.
